==> domainmodel-0.12.tar.gz: domainmodel-0.12/src/dm/dictionarywords.py <==
SYSTEM_NAME = 'system_name'
SYSTEM_TITLE = 'system_title'
SYSTEM_MODE = 'system_mode'
SYSTEM_VERSION = 'system_version'
SYSTEM_PACKAGE_NAME = 'system_package_name'
# Todo: Rename SYSTEM_SERVICE_ to SITE_.
SYSTEM_SERVICE_NAME = 'service_name'
SYSTEM_SERVICE_PATH = 'system_service_path'
SYSTEM_CONFIG_PATH = 'system_config_path'
PYTHONPATH = 'pythonpath'
PYTHONPATH_ALT = 'python_path'
ETC_DIR_PATH = 'etcdir'
VAR_DIR_PATH = 'vardir'
DB_URI = 'db.uri'
DB_TYPE = 'db.type'
DB_HOST = 'db.host'
DB_NAME = 'db.name'
DB_USER = 'db.user'
DB_PASS = 'db.pass'
DB_SUPER_USER = 'db.super_user'
DB_SUPER_PASS = 'db.super_pass'
OLD_DB_PASS = 'db.password'
DB_DELETE_COMMAND = 'db.delete_command'
DB_CREATE_COMMAND = 'db.create_command'
DB_MIGRATION_IN_PROGRESS = 'db.migration_in_progress'
PLUGIN_PACKAGE_NAME = 'plugin_package'
PLUGIN_DIR_PATH = 'plugin_data_dir'
VISITOR_NAME = 'visitor'
VISITOR_ROLE = 'visitor_role'  # rename to VISITOR_ROLE_NAME
INITIAL_PERSON_ROLE = 'person_role'  # rename to INITIAL_PERSON_ROLE_NAME
CAPTCHA_IS_ENABLED = 'captcha.enable'
LOG_PATH   = 'logging.log_file'
LOG_LEVEL  = 'logging.level'
DOMAIN_NAME = 'domain_name'
AUTH_COOKIE_NAME = 'auth_cookie_name'
NO_AUTH_COOKIE_NAME = 'no_auth_cookie_name'
AUTH_COOKIE_DOMAIN = 'auth_cookie_domain'
APACHE_CONFIG_PATH = 'www.apache_config_file'
WSGI_SCRIPT_PATH = 'www.wsgi_file'
SKIP_APACHE_RELOAD = 'www.no_reload_apache'
APACHE_RELOAD_CMD = 'www.reload_apache'
APACHE_CONFIGTEST_CMD = 'www.apache_configtest'
APACHE_IP_ADDRESS = 'www.ip_address'
HTTP_PORT = 'www.port_http'
HTTPS_PORT = 'www.port_https'
URI_PREFIX = 'www.uri_prefix'
MEDIA_PATH = 'www.media_dir'
OLD_MEDIA_PATH = 'www.media_root'
MEDIA_HOST = 'www.media_host'
MEDIA_PORT = 'www.media_port'
MEDIA_PREFIX = 'www.media_prefix'
TIMEZONE = 'environment.timezone'
SERVICE_EMAIL = 'email.service_address'
SMTP_HOST = 'email.smtp_host'
EMAIL_NOTIFY_CHANGES = 'email.notify_changes'
SKIP_EMAIL_SENDING = 'skip_email_sending'
IMAGES_DIR_PATH = 'images_dir'
WEBKIT_NAME = 'webkit_name'
WEBKIT_VERSION = 'webkit_version'
DJANGO_SECRET_KEY = 'django.secret_key'
DJANGO_TEMPLATES_DIR = 'django.templates_dir'
PYLONS_SECRET_KEY = 'pylons.secret_key'
PYLONS_TEMPLATES_DIR = 'pylons.templates_dir'
EDITOR = 'editor'
VIRTUALENVBIN_PATH = 'virtualenv.bin_dir'
SYSTEM_UP_SINCE = 'system_up_since'
MEMOS_LIMIT = 'memos.limit'
MEMOS_EXPIRE = 'memos.expire'
MEMOS_ENABLED = 'memos.enabled'
TEMPLATES_RESOURCE_PATH = 'resources.templates_dir'
MEDIA_RESOURCE_PATH = 'resources.media_dir'

==> domainmodel-0.14.tar.gz: domainmodel-0.14/src/dm/dictionarywords.py <==
SYSTEM_NAME = 'system_name'
SYSTEM_TITLE = 'system_title'
SYSTEM_MODE = 'system_mode'
SYSTEM_VERSION = 'system_version'
SYSTEM_PACKAGE_NAME = 'system_package_name'
# Todo: Rename SYSTEM_SERVICE_ to SITE_.
SYSTEM_SERVICE_NAME = 'service_name'
SYSTEM_SERVICE_PATH = 'system_service_path'
SYSTEM_CONFIG_PATH = 'system_config_path'
SYSTEM_USER_NAME = 'user_name'
FILESYSTEM_PATH = 'master_dir'
PYTHONPATH = 'pythonpath'
PYTHONPATH_ALT = 'python_path'
ETC_DIR_PATH = 'etcdir'
VAR_DIR_PATH = 'vardir'
DB_URI = 'db.uri'
DB_TYPE = 'db.type'
DB_HOST = 'db.host'
DB_NAME = 'db.name'
DB_USER = 'db.user'
DB_PASS = 'db.pass'
DB_SUPER_USER = 'db.super_user'
DB_SUPER_PASS = 'db.super_pass'
OLD_DB_PASS = 'db.password'
DB_DELETE_COMMAND = 'db.delete_command'
DB_CREATE_COMMAND = 'db.create_command'
DB_MIGRATION_IN_PROGRESS = 'db.migration_in_progress'
PLUGIN_PACKAGE_NAME = 'plugin_package'
PLUGIN_DIR_PATH = 'plugin_data_dir'
PASSWORD_DIGEST_SECRET = 'password_digest_secret'
VISITOR_NAME = 'visitor'
VISITOR_ROLE = 'visitor_role'  # rename to VISITOR_ROLE_NAME
INITIAL_PERSON_ROLE = 'person_role'  # rename to INITIAL_PERSON_ROLE_NAME
CAPTCHA_IS_ENABLED = 'captcha.enable'
LOG_PATH   = 'logging.log_file'
LOG_LEVEL  = 'logging.level'
DOMAIN_NAME = 'domain_name'
AUTH_COOKIE_NAME = 'auth_cookie_name'
NO_AUTH_COOKIE_NAME = 'no_auth_cookie_name'
AUTH_COOKIE_DOMAIN = 'auth_cookie_domain'
APACHE_CONFIG_PATH = 'www.apache_config_file'
APACHE_PYTHON_MODULE = 'www.python_module'
WSGI_SCRIPT_PATH = 'www.wsgi_file'
WSGI_PROCESS_GROUP = 'www.wsgi_process_group'
SKIP_APACHE_RELOAD = 'www.no_reload_apache'
APACHE_RELOAD_CMD = 'www.reload_apache'
APACHE_CONFIGTEST_CMD = 'www.apache_configtest'
APACHE_IP_ADDRESS = 'www.ip_address'
APACHE_WSGI_REDIRECT_DELAY = 'www.wsgi_redirect_delay'
HTTP_PORT = 'www.port_http'
HTTPS_PORT = 'www.port_https'
HTTP_AUTH_REALM = 'www.auth_realm'
URI_PREFIX = 'www.uri_prefix'
MEDIA_PATH = 'www.media_dir'
OLD_MEDIA_PATH = 'www.media_root'
MEDIA_HOST = 'www.media_host'
MEDIA_PORT = 'www.media_port'
MEDIA_PREFIX = 'www.media_prefix'
TIMEZONE = 'environment.timezone'
SERVICE_EMAIL = 'email.service_address'
SMTP_HOST = 'email.smtp_host'
EMAIL_NOTIFY_CHANGES = 'email.notify_changes'
ENABLE_EMAIL_SENDING = 'email.enable_sending'
IMAGES_DIR_PATH = 'images_dir'
WEBKIT_NAME = 'webkit_name'
WEBKIT_VERSION = 'webkit_version'
DJANGO_SECRET_KEY = 'django.secret_key'
DJANGO_TEMPLATES_DIR = 'django.templates_dir'
PYLONS_SECRET_KEY = 'pylons.secret_key'
PYLONS_TEMPLATES_DIR = 'pylons.templates_dir'
EDITOR = 'editor'
VIRTUALENVBIN_PATH = 'virtualenv.bin_dir'
SYSTEM_UP_SINCE = 'system_up_since'
MEMOS_LIMIT = 'memos.limit'
MEMOS_EXPIRE = 'memos.expire'
MEMOS_ENABLED = 'memos.enabled'
TEMPLATES_RESOURCE_PATH = 'resources.templates_dir'
MEDIA_RESOURCE_PATH = 'resources.media_dir'
